==> tw-server-common-2.4.3.1-20230816.100556-1-sources.jar: com/elitesland/tw/tw5/server/prd/system/entity/PrdSystemLogDO.java <==
package com.elitesland.tw.tw5.server.prd.system.entity;

import com.elitescloud.cloudt.common.annotation.Comment;
import com.elitescloud.cloudt.common.base.BaseModel;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * @author zoey
 * @Description:操作日志表
 * @date 2022/5/17 - 11:39
 */
@Entity
@Table(name = "prd_system_log",indexes = {})
@org.hibernate.annotations.Table(appliesTo = "prd_system_log", comment = "操作日志表")
@Data
@Getter
@Setter
@Where(clause = "delete_flag= 0")
//@NamedEntityGraphs({
//        @NamedEntityGraph(name = "system.log", attributeNodes = {
//                @NamedAttributeNode(value = "details")
//        }),
//})
public class PrdSystemLogDO extends BaseModel {

    @Comment("业务类型")
    @Column(name = "log_object")
    private String logObject;

    @Comment("业务对象主键id")
    @Column(name = "object_id")
    private Long objectId;

    @Comment("日志内容")
    @Column(name = "log_content")
    private String logContent;


//    @Comment("操作日志详情列表")
//    @OneToMany(fetch = FetchType.LAZY,cascade = CascadeType.ALL)
//    // @OrderColumn
//    @JoinColumn(name="logId")
//    private List<PrdSystemLogDetailDO> details;

//    @Comment("线索id")
//    @Column(name = "leads_id")
//    private Long leadsId;
//
//    @Comment("商机id")
//    @Column(name = "opportunity_id")
//    private Long opportunityId;
//
//    @Comment("市场活动（项目）id")
//    @Column(name = "market_id")
//    private Long marketId;
//
//    @Comment("潜在客户id")
//    @Column(name = "potential_customer_id")
//    private Long potentialCustomerId;
//
//    @Comment("客户id")
//    @Column(name = "customer_id")
//    private Long customerId;
//
//    @Comment("联系人id")
//    @Column(name = "contacts_id")
//    private Long contactsId;

    //TODO: 需要的往后加
    @Comment("扩展字段1")
    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;
}

==> tw-server-common-3.0.1-20230927.093446-1-sources.jar: com/elitesland/tw/tw5/server/prd/system/entity/PrdSystemLogDO.java <==
package com.elitesland.tw.tw5.server.prd.system.entity;

import com.elitescloud.cloudt.common.annotation.Comment;
import com.elitescloud.boot.model.entity.BaseModel;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * @author zoey
 * @Description:操作日志表
 * @date 2022/5/17 - 11:39
 */
@Entity
@Table(name = "prd_system_log",indexes = {})
@org.hibernate.annotations.Table(appliesTo = "prd_system_log", comment = "操作日志表")
@Data
@Getter
@Setter
@Where(clause = "delete_flag= 0")
//@NamedEntityGraphs({
//        @NamedEntityGraph(name = "system.log", attributeNodes = {
//                @NamedAttributeNode(value = "details")
//        }),
//})
public class PrdSystemLogDO extends BaseModel {

    @Comment("业务类型")
    @Column(name = "log_object")
    private String logObject;

    @Comment("业务对象主键id")
    @Column(name = "object_id")
    private Long objectId;

    @Comment("日志内容")
    @Column(name = "log_content")
    private String logContent;


//    @Comment("操作日志详情列表")
//    @OneToMany(fetch = FetchType.LAZY,cascade = CascadeType.ALL)
//    // @OrderColumn
//    @JoinColumn(name="logId")
//    private List<PrdSystemLogDetailDO> details;

//    @Comment("线索id")
//    @Column(name = "leads_id")
//    private Long leadsId;
//
//    @Comment("商机id")
//    @Column(name = "opportunity_id")
//    private Long opportunityId;
//
//    @Comment("市场活动（项目）id")
//    @Column(name = "market_id")
//    private Long marketId;
//
//    @Comment("潜在客户id")
//    @Column(name = "potential_customer_id")
//    private Long potentialCustomerId;
//
//    @Comment("客户id")
//    @Column(name = "customer_id")
//    private Long customerId;
//
//    @Comment("联系人id")
//    @Column(name = "contacts_id")
//    private Long contactsId;

    //TODO: 需要的往后加
    @Comment("扩展字段1")
    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;
}
